@@ -241,10 +241,12 @@ if ! $skip_gnulib; then
     stdlib-h
     stpcpy
     stpncpy
+    str_startswith
     strchrnul
     strcspn
     strerror
     string-desc
+    strnlen
     strpbrk
     strtol
     strtoul
@@ -255,7 +257,10 @@ if ! $skip_gnulib; then
     trim
     unicase/u8-casefold
     unictype/ctype-space
+    unictype/property-white-space
     unictype/syntax-java-whitespace
+    unictype/property-xid-start
+    unictype/property-xid-continue
     unilbrk/ulc-width-linebreaks
     uniname/uniname
     uninorm/nfc
@@ -269,6 +274,7 @@ if ! $skip_gnulib; then
     unlocked-io
     unsetenv
     vasprintf
+    vc-mtime
     wait-process
     write
     xalloc
@@ -325,6 +331,7 @@ if ! $skip_gnulib; then
     javaexec-script
     manywarnings
     stdint-h
+    test-xfail
   '
   GNULIB_MODULES_TOOLS_LIBUNISTRING_TESTS='
     unilbrk/u8-possible-linebreaks-tests
@@ -336,7 +343,6 @@ if ! $skip_gnulib; then
   GNULIB_MODULES_LIBGETTEXTLIB="$GNULIB_MODULES_TOOLS_FOR_SRC $GNULIB_MODULES_TOOLS_FOR_SRC_COMMON_DEPENDENCIES $GNULIB_MODULES_TOOLS_OTHER"
   $GNULIB_TOOL --dir=gettext-tools --lib=libgettextlib --source-base=gnulib-lib --m4-base=gnulib-m4 --tests-base=gnulib-tests --makefile-name=Makefile.gnulib --libtool --with-tests --local-dir=gnulib-local --local-symlink \
     --import \
-    --avoid=float-h-tests \
     --avoid=fdutimensat-tests --avoid=futimens-tests --avoid=utime-tests --avoid=utimens-tests --avoid=utimensat-tests \
     --avoid=array-list-tests --avoid=linked-list-tests --avoid=linkedhash-list-tests \
     `for m in $GNULIB_MODULES_TOOLS_LIBUNISTRING_TESTS; do echo --avoid=$m; done` \
@@ -347,7 +353,7 @@ if ! $skip_gnulib; then
     mbrlen
     regex
   '
-  $GNULIB_TOOL --dir=gettext-tools --macro-prefix=grgl --source-base=libgrep/gnulib-lib --m4-base=libgrep/gnulib-m4 --makefile-name=Makefile.gnulib --witness-c-macro=IN_GETTEXT_TOOLS_LIBGREP --local-dir=gnulib-local --local-symlink \
+  $GNULIB_TOOL --dir=gettext-tools --macro-prefix=grgl --lib=libgrep --source-base=libgrep --m4-base=libgrep/gnulib-m4 --witness-c-macro=IN_GETTEXT_TOOLS_LIBGREP --makefile-name=Makefile.gnulib --local-dir=gnulib-local --local-symlink \
     --import \
     `for m in $GNULIB_MODULES_TOOLS_FOR_SRC_COMMON_DEPENDENCIES; do \
        if test \`$GNULIB_TOOL --extract-applicability $m\` != all; then \
@@ -391,10 +397,15 @@ if ! $skip_gnulib; then
     stdlib-h
     stpcpy
     stpncpy
+    str_startswith
     strchrnul
     strerror
     string-desc
+    strnlen
     unictype/ctype-space
+    unictype/property-white-space
+    unictype/property-xid-start
+    unictype/property-xid-continue
     unilbrk/ulc-width-linebreaks
     unistr/u8-mbtouc
     unistr/u8-mbtoucr
@@ -464,6 +475,8 @@ if ! $skip_gnulib; then
   $GNULIB_TOOL --copy-file build-aux/update-copyright || exit $?
   $GNULIB_TOOL --copy-file build-aux/useless-if-before-free || exit $?
   $GNULIB_TOOL --copy-file build-aux/vc-list-files || exit $?
+  $GNULIB_TOOL --copy-file m4/init-package-version.m4 || exit $?
+  $GNULIB_TOOL --copy-file m4/version-stamp.m4 || exit $?
   $GNULIB_TOOL --copy-file top/GNUmakefile . || exit $?
   $GNULIB_TOOL --copy-file top/maint.mk . || exit $?
 
